==> prestashop_1.4.0.7.zip: prestashop/modules/watermark/es.php <==
<?php

global $_MODULE;
$_MODULE = array();
$_MODULE['<{watermark}prestashop>watermark_ee20bb60493f049175fc10c35acd2272'] = 'Marca de agua (filigrana)';
$_MODULE['<{watermark}prestashop>watermark_929bfd56c7ec447627de0591f78d2008'] = 'Proteja la imagen por una marca de agua';
$_MODULE['<{watermark}prestashop>watermark_fa214007826415a21a8456e3e09f999d'] = '¿Está seguro de querer suprimir los detalles?';
$_MODULE['<{watermark}prestashop>watermark_ea736631ca0a09439fe41b084ae38a74'] = 'La imagen de la Marca de agua (filigrana) tiene que ser cargada para que este módulo funcione correctamente';
$_MODULE['<{watermark}prestashop>watermark_5bece498c51bbfc90b1f4c11120590e6'] = 'La transparencia es obligatoria';
$_MODULE['<{watermark}prestashop>watermark_78d0b1c450a31c9728488a6b0a893e8a'] = 'La transparencia no esta en la gama permitida';
$_MODULE['<{watermark}prestashop>watermark_d31c2d99614d8e16430d2d8c99c1f2b0'] = 'Se necesita alineación Y';
$_MODULE['<{watermark}prestashop>watermark_8fe9c39f4bf87082caabcf3650970c71'] = 'Alineación Y no permitida.';
$_MODULE['<{watermark}prestashop>watermark_c2cf8e33c907a4cc689881dc8fa571c2'] = 'Se necesita alineación X';
$_MODULE['<{watermark}prestashop>watermark_3a1f788dbe8957be92048606cf0d3fcb'] = 'Alineación X no permitida.';
$_MODULE['<{watermark}prestashop>watermark_a9cac4be0fa0b815376b96f49e1435d7'] = 'Se requiere al menos un tipo de imagen.';
$_MODULE['<{watermark}prestashop>watermark_3deee3a74625e5d28cdeba65f9c449dc'] = 'la imagen debe estar en formato GIF';
$_MODULE['<{watermark}prestashop>watermark_444bcb3a3fcf8389296c49467f27e1d6'] = 'ok';
$_MODULE['<{watermark}prestashop>watermark_c888438d14855d7d96a2724ee9c306bd'] = 'Ajustes actualizados';
$_MODULE['<{watermark}prestashop>watermark_c0275788cf97660b52ab23f1f8c7c8d7'] = 'Detalles de la filigrana';
$_MODULE['<{watermark}prestashop>watermark_ac4bc3c760ecb9efef11c604551f7fa9'] = 'Una vez que haya creado el módulo, tiene que regenerar las imágenes a utilizar en la herramienta Preferencias> Imágenes. Sin embargo, la filigrana se añadirá automáticamente en las nuevas imágenes.';
$_MODULE['<{watermark}prestashop>watermark_f237761e479d501b4ec1ebe0ef8947cb'] = 'La marca de agua no se ha subido';
$_MODULE['<{watermark}prestashop>watermark_c9519bff5a6fe31e0f26b1c52dad7ad8'] = 'Archivo de la filigrana';
$_MODULE['<{watermark}prestashop>watermark_6ceef3b44f3ca247b2d32b5e934a4d9d'] = 'Debe estar en formato GIF';
$_MODULE['<{watermark}prestashop>watermark_3ccc25c1409aec574beb82bad14b5ebc'] = 'Transparencia de la marca de agua (0-100)';
$_MODULE['<{watermark}prestashop>watermark_acf0fa79a73731e7d70cb208a62c249a'] = 'Alineación X de la marca de agua';
$_MODULE['<{watermark}prestashop>watermark_489f2e730102b59aec48b5c27d2cbe1c'] = 'Alineación Y de la marca de agua';
$_MODULE['<{watermark}prestashop>watermark_bd75d3144c69854488e26ae437bfc2f8'] = 'Elija el tipo de imagen para proteger la filigrana';
$_MODULE['<{watermark}prestashop>watermark_b17f3f4dcf653a5776792498a9b44d6a'] = 'Ajustes actualizados';
$_MODULE['<{watermark}prestashop>watermark_a472c2655d993574100fc8e2c940fc05'] = 'Su imagen filigrana no es un verdadero formato gif, conviértalo en lugar de renombrarlo';

==> prestashop_1.4.0.10.zip: prestashop/modules/watermark/es.php <==
<?php

global $_MODULE;
$_MODULE = array();
$_MODULE['<{watermark}prestashop>watermark_ee20bb60493f049175fc10c35acd2272'] = 'Marca de agua (filigrana)';
$_MODULE['<{watermark}prestashop>watermark_929bfd56c7ec447627de0591f78d2008'] = 'Proteja la imagen por una marca de agua';
$_MODULE['<{watermark}prestashop>watermark_fa214007826415a21a8456e3e09f999d'] = '¿Está seguro de querer suprimir los detalles?';
$_MODULE['<{watermark}prestashop>watermark_ea736631ca0a09439fe41b084ae38a74'] = 'La imagen de la Marca de agua (filigrana) tiene que ser cargada para que este módulo funcione correctamente';
$_MODULE['<{watermark}prestashop>watermark_5bece498c51bbfc90b1f4c11120590e6'] = 'La transparencia es obligatoria';
$_MODULE['<{watermark}prestashop>watermark_78d0b1c450a31c9728488a6b0a893e8a'] = 'La transparencia no esta en la gama permitida';
$_MODULE['<{watermark}prestashop>watermark_d31c2d99614d8e16430d2d8c99c1f2b0'] = 'Se necesita alineación Y';
$_MODULE['<{watermark}prestashop>watermark_8fe9c39f4bf87082caabcf3650970c71'] = 'Alineación Y no permitida.';
$_MODULE['<{watermark}prestashop>watermark_c2cf8e33c907a4cc689881dc8fa571c2'] = 'Se necesita alineación X';
$_MODULE['<{watermark}prestashop>watermark_3a1f788dbe8957be92048606cf0d3fcb'] = 'Alineación X no permitida.';
$_MODULE['<{watermark}prestashop>watermark_a9cac4be0fa0b815376b96f49e1435d7'] = 'Se requiere al menos un tipo de imagen.';
$_MODULE['<{watermark}prestashop>watermark_dce32581fd55ad87ecd22a06e97ede00'] = 'La imagen debe ser en formato  GIF';
$_MODULE['<{watermark}prestashop>watermark_444bcb3a3fcf8389296c49467f27e1d6'] = 'ok';
$_MODULE['<{watermark}prestashop>watermark_c888438d14855d7d96a2724ee9c306bd'] = 'Ajustes actualizados';
$_MODULE['<{watermark}prestashop>watermark_c0275788cf97660b52ab23f1f8c7c8d7'] = 'Detalles de la filigrana';
$_MODULE['<{watermark}prestashop>watermark_ac4bc3c760ecb9efef11c604551f7fa9'] = 'Una vez que haya creado el módulo, tiene que regenerar las imágenes a utilizar en la herramienta Preferencias> Imágenes. Sin embargo, la filigrana se añadirá automáticamente en las nuevas imágenes.';
$_MODULE['<{watermark}prestashop>watermark_f237761e479d501b4ec1ebe0ef8947cb'] = 'La marca de agua no se ha subido';
$_MODULE['<{watermark}prestashop>watermark_c9519bff5a6fe31e0f26b1c52dad7ad8'] = 'Archivo de la filigrana';
$_MODULE['<{watermark}prestashop>watermark_ce4ca541df51a63fd8e78e0da29e1d44'] = 'Debe ser en formato GIF';
$_MODULE['<{watermark}prestashop>watermark_3ccc25c1409aec574beb82bad14b5ebc'] = 'Transparencia de la marca de agua (0-100)';
$_MODULE['<{watermark}prestashop>watermark_acf0fa79a73731e7d70cb208a62c249a'] = 'Alineación X de la marca de agua';
$_MODULE['<{watermark}prestashop>watermark_489f2e730102b59aec48b5c27d2cbe1c'] = 'Alineación Y de la marca de agua';
$_MODULE['<{watermark}prestashop>watermark_bd75d3144c69854488e26ae437bfc2f8'] = 'Elija el tipo de imagen para proteger la filigrana';
$_MODULE['<{watermark}prestashop>watermark_b17f3f4dcf653a5776792498a9b44d6a'] = 'Ajustes actualizados';
$_MODULE['<{watermark}prestashop>watermark_a472c2655d993574100fc8e2c940fc05'] = 'Su imagen filigrana no es un verdadero formato gif, conviértalo en lugar de renombrarlo';
